@@ -167,6 +167,7 @@ CalculateBarcodeInflections <- function(
 #' @param downstream Number of bases downstream to consider
 #' @param verbose Print progress/messages
 #'
+#' @importFrom future nbrOfWorkers
 #' @export
 #'
 CreateGeneActivityMatrix <- function(
@@ -218,7 +219,7 @@ CreateGeneActivityMatrix <- function(
   peak.matrix <- as(object = peak.matrix, Class = 'matrix')
   all.features <- unique(x = annotations$new_feature)
 
-  if (PlanThreads() > 1) {
+  if (nbrOfWorkers() > 1) {
     mysapply <- future_sapply
   } else {
     mysapply <- ifelse(test = verbose, yes = pbsapply, no = sapply)
@@ -407,6 +408,76 @@ HTODemux <- function(
   return(object)
 }
 
+#' Calculate pearson residuals of features not in the scale.data
+#'
+#' This function calls sctransform::get_residuals.
+#'
+#' @param object A seurat object
+#' @param features Name of features to add into the scale.data
+#' @param assay Name of the assay of the seurat object generated by SCTransform
+#' @param verbose Whether to print messages and progress bars
+#'
+#' @return Returns a Seurat object containing  pearson residuals of added features in its scale.data
+#'
+#' @importFrom sctransform get_residuals
+#'
+#' @export
+#'
+#' @seealso \code{\link[sctransform]{get_residuals}}
+#'
+#' @examples
+#' pbmc_small <- SCTransform(object = pbmc_small, variable.features.n = 20)
+#' pbmc_small <- GetResidual(object = pbmc_small, features = c('MS4A1', 'TCL1A'))
+#'
+GetResidual <- function(object, features, assay = "SCT", verbose = TRUE) {
+  if (is.null(x = Misc(object[[assay]], slot = 'vst.out'))) {
+    stop(assay, " assay was not generated by SCTransform")
+  }
+  new_features <- setdiff(
+    x = features,
+    y = rownames(x = GetAssayData(object = object, assay = assay, slot = "scale.data"))
+  )
+  if (length(x = new_features) == 0) {
+    if (verbose) {
+      message("Pearson residuals of input features exist already")
+    }
+  } else {
+    vst_out <- Misc(object = object[[assay]], slot = 'vst.out')
+    diff_features <- setdiff(
+      x = new_features,
+      y = rownames(x = GetAssayData(object = object, assay = assay, slot = "counts"))
+    )
+    intersect_feature <- intersect(
+      x = new_features,
+      y = rownames(x = GetAssayData(object = object, assay = assay, slot = "counts"))
+    )
+    if (length(x = diff_features) == 0) {
+      umi <- GetAssayData(object = object, assay = assay, slot = "counts" )[new_features, , drop = FALSE]
+    } else {
+      warning("The following ", length(x = diff_features), " features do not exist in the counts slot: ", paste(diff_features, collapse = " "))
+      umi <- GetAssayData(object = object, assay = assay, slot = "counts" )[intersect_feature, , drop = FALSE]
+    }
+    new_residual <- get_residuals(
+      vst_out = vst_out,
+      umi = umi,
+      residual_type = "pearson",
+      show_progress = verbose
+    )
+    new_residual <- as.matrix(x = new_residual)
+    object <- SetAssayData(
+      object = object,
+      slot = 'scale.data',
+      new.data = rbind(
+        GetAssayData(object = object, slot = 'scale.data', assay = assay),
+        new_residual
+      ),
+      assay = assay
+    )
+  }
+  return(object)
+}
+
+
 #' Normalize raw data
 #'
 #' Normalize count data per cell and transform to log scale
@@ -454,7 +525,7 @@ LogNormalize <- function(data, scale.factor = 1e4, verbose = TRUE, ...) {
 #' @param assay Name of the multiplexing assay (HTO by default)
 #' @param quantile The quantile to use for classification
 #' @param autoThresh Whether to perform automated threshold finding to define the best quantile. Default is FALSE
-#' @param maxiter Maximum number of iterations if autoThresh = TRUE. Default is
+#' @param maxiter Maximum number of iterations if autoThresh = TRUE. Default is 5
 #' @param qrange A range of possible quantile values to try if autoThresh = TRUE
 #' @param verbose Prints the output
 #'
@@ -984,6 +1055,7 @@ SampleUMI <- function(
 #' @param assay Name of assay to pull the count data from; default is 'RNA'
 #' @param new.assay.name Name for the new assay containing the normalized data
 #' @param do.correct.umi Place corrected UMI matrix in assay counts slot; default is TRUE
+#' @param ncells Number of subsampling cells used to build NB regression; default is NULL
 #' @param variable.features.n Use this many features as variable features after
 #' ranking by residual variance; default is 3000
 #' @param variable.features.rv.th Instead of setting a fixed number of variable features,
@@ -999,7 +1071,7 @@ SampleUMI <- function(
 #' created in full; useful for large data sets, but will take longer to run;
 #' this will also set return.only.var.genes to TRUE; default is FALSE
 #' @param return.only.var.genes If set to TRUE the scale.data matrices in output assay are
-#' subset to contain only the variable genes; default is FALSE
+#' subset to contain only the variable genes; default is TRUE
 #' @param seed.use Set a random seed. By default, sets the seed to 1448145. Setting
 #' NULL will not set a seed.
 #' @param verbose Whether to print messages and progress bars
@@ -1023,6 +1095,7 @@ SCTransform <- function(
   assay = 'RNA',
   new.assay.name = 'SCT',
   do.correct.umi = TRUE,
+  ncells = NULL,
   variable.features.n = 3000,
   variable.features.rv.th = 1.3,
   vars.to.regress = NULL,
@@ -1060,7 +1133,6 @@ SCTransform <- function(
   if (any(!vars.to.regress %in% colnames(x = cell.attr))) {
     stop('problem with second non-regularized linear regression; not all variables found in seurat object meta data; check vars.to.regress parameter')
   }
-  
   if (any(c('cell_attr', 'show_progress', 'return_cell_attr', 'return_gene_attr', 'return_corrected_umi') %in% names(x = vst.args))) {
     warning(
       'the following arguments will be ignored because they are set within this function:',
@@ -1084,6 +1156,7 @@ SCTransform <- function(
   vst.args[['return_cell_attr']] <- TRUE
   vst.args[['return_gene_attr']] <- TRUE
   vst.args[['return_corrected_umi']] <- do.correct.umi
+  vst.args[['n_cells']] <- ncells
   residual.type <- vst.args[['residual_type']] %||% 'pearson'
   res.clip.range <- vst.args[['res_clip_range']] %||% c(-sqrt(x = ncol(x = umi)), sqrt(x = ncol(x = umi)))
   if (conserve.memory) {
@@ -1529,6 +1602,7 @@ FindVariableFeatures.Seurat <- function(
 }
 
 #' @importFrom future.apply future_lapply
+#' @importFrom future nbrOfWorkers
 #'
 #' @param normalization.method Method for normalization.
 #'  \itemize{
@@ -1561,7 +1635,7 @@ NormalizeData.default <- function(
   if (is.null(x = normalization.method)) {
     return(object)
   }
-  normalized.data <- if (PlanThreads() > 1) {
+  normalized.data <- if (nbrOfWorkers() > 1) {
     norm.function <- switch(
       EXPR = normalization.method,
       'LogNormalize' = LogNormalize,
@@ -1586,7 +1660,7 @@ NormalizeData.default <- function(
     )
     chunk.points <- ChunkPoints(
       dsize = dsize,
-      csize = block.size %||% ceiling(x = dsize / PlanThreads())
+      csize = block.size %||% ceiling(x = dsize / nbrOfWorkers())
     )
     normalized.data <- future_lapply(
       X = 1:ncol(x = chunk.points),
@@ -1885,6 +1959,8 @@ RunALRA.Seurat <- function(
   return(object)
 }
 
+#' @importFrom future nbrOfWorkers
+#'
 #' @param features Vector of features names to scale/center. Default is all features
 #' @param vars.to.regress Variables to regress out (previously latent.vars in
 #' RegressOut). For example, nUMI, or percent.mito.
@@ -1909,7 +1985,7 @@ RunALRA.Seurat <- function(
 #' don't block for scaling calculations.
 #' @param verbose Displays a progress bar for scaling procedure
 #'
-#' @importFrom future.apply future_apply
+#' @importFrom future.apply future_lapply
 #'
 #' @rdname ScaleData
 #' @export
@@ -1961,15 +2037,16 @@ ScaleData.default <- function(
       message("Regressing out ", paste(vars.to.regress, collapse = ', '))
     }
     chunk.points <- ChunkPoints(dsize = nrow(x = object), csize = block.size)
-    if (PlanThreads() > 1) {
-      object <- future_apply(
-        X = expand.grid(
-          names(x = split.cells),
-          1:ncol(x = chunk.points),
-          stringsAsFactors = FALSE
-        ),
-        MARGIN = 1,
-        FUN = function(row) {
+    if (nbrOfWorkers() > 1) { # TODO: lapply
+      chunks <- expand.grid(
+        names(x = split.cells),
+        1:ncol(x = chunk.points),
+        stringsAsFactors = FALSE
+      )
+      object <- future_lapply(
+        X = 1:nrow(x = chunks),
+        FUN = function(i) {
+          row <- chunks[i, ]
           group <- row[[1]]
           index <- as.numeric(x = row[[2]])
           return(RegressOutMatrix(
@@ -1996,10 +2073,8 @@ ScaleData.default <- function(
           }
         )
         object <- do.call(what = 'cbind', args = object)
-      } else if (is.list(x = object)) {
-        object <- do.call(what = 'rbind', args = object)
       } else {
-        dim(x = object) <- lapply(X = object.names, FUN = length)
+        object <- do.call(what = 'rbind', args = object)
       }
     } else {
       object <- lapply(
@@ -2044,16 +2119,17 @@ ScaleData.default <- function(
     object <- as.matrix(x = object)
     scale.function <- FastRowScale
   }
-  if (PlanThreads() > 1) {
+  if (nbrOfWorkers() > 1) {
     blocks <- ChunkPoints(dsize = length(x = features), csize = block.size)
-    scaled.data <- future_apply(
-      X = expand.grid(
-        names(x = split.cells),
-        1:ncol(x = blocks),
-        stringsAsFactors = FALSE
-      ),
-      MARGIN = 1,
-      FUN = function(row) {
+    chunks <- expand.grid(
+      names(x = split.cells),
+      1:ncol(x = blocks),
+      stringsAsFactors = FALSE
+    )
+    scaled.data <- future_lapply(
+      X = 1:nrow(x = chunks),
+      FUN = function(index) {
+        row <- chunks[index, ]
         group <- row[[1]]
         block <- as.vector(x = blocks[, as.numeric(x = row[[2]])])
         data.scale <- scale.function(
@@ -2083,10 +2159,8 @@ ScaleData.default <- function(
         }
       )
       scaled.data <- suppressWarnings(expr = do.call(what = 'cbind', args = scaled.data))
-    } else if (is.list(x = scaled.data)) {
-      suppressWarnings(expr = scaled.data <- do.call(what = 'rbind', args = scaled.data))
     } else {
-      dim(x = scaled.data) <- dim(x = object)
+      suppressWarnings(expr = scaled.data <- do.call(what = 'rbind', args = scaled.data))
     }
   } else {
     scaled.data <- matrix(
